@@ -20,9 +20,13 @@ from polly.errors import (
     InvalidParameterException,
     error_handler,
     is_unfinished_query_error,
-    paramException, wrongParamException, apiErrorException
+    paramException,
+    wrongParamException,
+    apiErrorException,
+    invalidApiResponseException,
 )
 from deprecated import deprecated
+from polly.index_schema_level_conversion_const import indexes_schema_level_map
 
 QUERY_API_V1 = "v1"
 QUERY_API_V2 = "v2"
@@ -33,7 +37,9 @@ class OmixAtlas:
         self.session = Polly.get_session(token, env=env)
         self.base_url = f"https://v2.api.{self.session.env}.elucidata.io"
         self.discover_url = f"https://api.discover.{self.session.env}.elucidata.io"
-        self.elastic_url = f"https://api.datalake.discover.{self.session.env}.elucidata.io/elastic"
+        self.elastic_url = (
+            f"https://api.datalake.discover.{self.session.env}.elucidata.io/elastic"
+        )
         self.resource_url = f"{self.base_url}/v1/omixatlases"
 
     def get_all_omixatlas(self):
@@ -69,39 +75,27 @@ class OmixAtlas:
         queries_payload = {
             "data": {
                 "type": "queries",
-                "attributes": {
-                    "query": query,
-                    "query_api_version": query_api_version
-                }
+                "attributes": {"query": query, "query_api_version": query_api_version},
             }
         }
         if experimental_features is not None:
-            queries_payload.update({
-                "experimental_features": experimental_features
-            })
+            queries_payload.update({"experimental_features": experimental_features})
 
         response = self.session.post(queries_url, json=queries_payload)
         error_handler(response)
 
         query_data = response.json().get("data")
         query_id = query_data.get("id")
-        return self._process_query_to_completion(
-            query_id,
-            query_api_version,
-            page_size
-        )
+        return self._process_query_to_completion(query_id, query_api_version, page_size)
 
     @retry(
         retry_on_exception=is_unfinished_query_error,
-        wait_exponential_multiplier=500,   # Exponential back-off starting 500ms
-        wait_exponential_max=10000,        # After 10s, retry every 10s
-        stop_max_delay=300000              # Stop retrying after 300s (5m)
+        wait_exponential_multiplier=500,  # Exponential back-off starting 500ms
+        wait_exponential_max=10000,  # After 10s, retry every 10s
+        stop_max_delay=300000,  # Stop retrying after 300s (5m)
     )
     def _process_query_to_completion(
-        self,
-        query_id: str,
-        query_api_version: str,
-        page_size: Union[int, None]
+        self, query_id: str, query_api_version: str, page_size: Union[int, None]
     ):
         queries_url = f"{self.resource_url}/queries/{query_id}"
         response = self.session.get(queries_url)
@@ -110,11 +104,7 @@ class OmixAtlas:
         query_data = response.json().get("data")
         query_status = query_data.get("attributes", {}).get("status")
         if query_status == "succeeded":
-            return self._handle_query_success(
-                query_data,
-                query_api_version,
-                page_size
-            )
+            return self._handle_query_success(query_data, query_api_version, page_size)
         elif query_status == "failed":
             self._handle_query_failure(query_data)
         else:
@@ -125,35 +115,23 @@ class OmixAtlas:
         raise QueryFailedException(fail_msg)
 
     def _handle_query_success(
-        self,
-        query_data: dict,
-        query_api_version: str,
-        page_size: Union[int, None]
+        self, query_data: dict, query_api_version: str, page_size: Union[int, None]
     ) -> pd.DataFrame:
         query_id = query_data.get("id")
 
         details = []
         time_taken_in_ms = query_data.get("attributes").get("exec_time_ms")
         if isinstance(time_taken_in_ms, int):
-            details.append(
-                "time taken: {:.2f} seconds".format(time_taken_in_ms / 1000)
-            )
-        data_scanned_in_bytes = query_data.get("attributes").get(
-            "data_scanned_bytes"
-        )
+            details.append("time taken: {:.2f} seconds".format(time_taken_in_ms / 1000))
+        data_scanned_in_bytes = query_data.get("attributes").get("data_scanned_bytes")
         if isinstance(data_scanned_in_bytes, int):
             details.append(
-                "data scanned: {:.3f} MB".format(
-                    data_scanned_in_bytes / (1024 ** 2)
-                )
+                "data scanned: {:.3f} MB".format(data_scanned_in_bytes / (1024**2))
             )
 
         if details:
             detail_str = ", ".join(details)
-            print(
-                "Query execution succeeded "
-                f"({detail_str})"
-            )
+            print("Query execution succeeded " f"({detail_str})")
         else:
             print("Query execution succeeded")
 
@@ -164,15 +142,12 @@ class OmixAtlas:
 
     def _fetch_results_as_pages(self, query_id, page_size):
         first_page_url = (
-            f"{self.resource_url}/queries/{query_id}"
-            f"/results?page[size]={page_size}"
+            f"{self.resource_url}/queries/{query_id}" f"/results?page[size]={page_size}"
         )
         response = self.session.get(first_page_url)
         error_handler(response)
         result_data = response.json()
-        rows = [
-            row_data.get("attributes") for row_data in result_data.get("data")
-        ]
+        rows = [row_data.get("attributes") for row_data in result_data.get("data")]
 
         all_rows = rows
 
@@ -190,8 +165,7 @@ class OmixAtlas:
             result_data = response.json()
             if result_data.get("data"):
                 rows = [
-                    row_data.get("attributes")
-                    for row_data in result_data.get("data")
+                    row_data.get("attributes") for row_data in result_data.get("data")
                 ]
             else:
                 rows = []
@@ -211,9 +185,7 @@ class OmixAtlas:
         error_handler(response)
         result_data = response.json()
 
-        results_file_download_url = result_data.get("data", {}).get(
-            "download_url"
-        )
+        results_file_download_url = result_data.get("data", {}).get("download_url")
         if (
             results_file_download_url is None
             or results_file_download_url == "Not available"
@@ -223,8 +195,7 @@ class OmixAtlas:
 
         def _local_temp_file_path(filename):
             temp_dir = Path(
-                "/tmp" if platform.system() == "Darwin"
-                else tempfile.gettempdir()
+                "/tmp" if platform.system() == "Darwin" else tempfile.gettempdir()
             ).absolute()
 
             temp_file_path = os.path.join(temp_dir, filename)
@@ -236,7 +207,7 @@ class OmixAtlas:
         def _download_file_stream(download_url, _local_file_path):
             with requests.get(download_url, stream=True, headers={}) as r:
                 r.raise_for_status()
-                with open(_local_file_path, 'wb') as f:
+                with open(_local_file_path, "wb") as f:
                     for chunk in r.iter_content(chunk_size=8192):
                         f.write(chunk)
 
@@ -248,49 +219,98 @@ class OmixAtlas:
 
         return data_df
 
-    def get_schema_from_api(self, repo_id: str, schema_type_dict: dict) -> dict:
+    def get_schema_from_api(
+        self, repo_key: str, schema_type_dict: dict, source: str, data_type: str
+    ) -> dict:
         """
-            Gets the schema of a repo id for the given repo_id and
-            schema_type definition at the top level
-            params:
-            repo_id => str
-            schema_type_dict => dictionary {schema_level:schema_type}
-            example {'dataset': 'files', 'sample': 'gct_metadata'}
-            Ouput:
-                {
-                    "data": {
-                        "id": "<REPO_ID>",
-                        "type": "schema",
-                        "attributes": {
-                            "schema_type": "files | gct_metadata | h5ad_metadata",
-                            "schema": {
-                                ... field definitions
-                            }
+        Gets the schema of a repo id for the given repo_key and
+        schema_type definition at the top level
+        params:
+        repo_key => str
+        schema_type_dict => dictionary {schema_level:schema_type}
+        example {'dataset': 'files', 'sample': 'gct_metadata'}
+        Ouput:
+            {
+                "data": {
+                    "id": "<REPO_ID>",
+                    "type": "schema",
+                    "attributes": {
+                        "schema_type": "files | gct_metadata | h5ad_metadata",
+                        "schema": {
+                            ... field definitions
                         }
                     }
                 }
+            }
         """
         resp_dict = {}
-        schema_base_url = f'{self.discover_url}/repositories'
-        summary_query_param = '?response_format=summary'
-        if repo_id and schema_type_dict and isinstance(schema_type_dict, Dict):
+        schema_base_url = f"{self.discover_url}/repositories"
+        summary_query_param = "?response_format=summary"
+        filter_query_params = ""
+        if source:
+            if data_type:
+                filter_query_params = f"&source={source}&datatype={data_type}"
+            else:
+                filter_query_params = f"&source={source}"
+        if repo_key and schema_type_dict and isinstance(schema_type_dict, Dict):
             for key, val in schema_type_dict.items():
                 schema_type = val
-                dataset_url = f"{schema_base_url}/{repo_id}/schemas/{schema_type}{summary_query_param}"
+                if filter_query_params:
+                    dataset_url = (
+                        f"{schema_base_url}/{repo_key}/"
+                        + f"schemas/{schema_type}"
+                        + f"{summary_query_param}{filter_query_params}"
+                    )
+                else:
+                    dataset_url = f"{schema_base_url}/{repo_key}/schemas/{schema_type}{summary_query_param}"
                 resp = self.session.get(dataset_url)
                 error_handler(resp)
-                resp_dict[key] = resp.json()
+                # making `schema_type` from the API response
+                # as the key of resp_dict
+                api_resp_dict = resp.json()
+                if "data" in api_resp_dict:
+                    if "attributes" in api_resp_dict["data"]:
+                        if "schema_type" in api_resp_dict["data"]["attributes"]:
+                            schema_type_key = api_resp_dict["data"]["attributes"][
+                                "schema_type"
+                            ]
+                        else:
+                            raise invalidApiResponseException(
+                                title="schema_type not present",
+                                detail="schema_type not present in the repository schema",
+                            )
+                    else:
+                        raise invalidApiResponseException(
+                            title="attributes not present",
+                            detail="attributes not present in the repository schema",
+                        )
+                else:
+                    raise invalidApiResponseException(
+                        title="data key not present",
+                        detail="data key not present in the repository schema",
+                    )
+                resp_dict[schema_type_key] = resp.json()
         else:
             raise paramException(
                 title="Param Error",
-                detail="repo_id and schema_type_dict are either empty or its datatype is not correct"
+                detail="repo_key and schema_type_dict are either empty or its datatype is not correct",
             )
         return resp_dict
 
-    def get_schema(self, repo_id: str, schema_level=['dataset', 'sample'], data_type="others") -> dict:
+    def get_schema(
+        self, repo_key: str, schema_level=["dataset", "sample"], source="", data_type=""
+    ) -> dict:
         """
-            Visualizing the schema of the repository depending on schema_type
-            schema_type : gct_metadata or h5ad_metadata i.e Column Fields (Sample)
+        Input params:
+                repo_key => str => <owner_name.repo_name>/<repo_id>
+                schema_level => list => Default value => ['dataset', 'sample']
+            Output:
+                {
+                    'dataset':pd.DataFrame,
+                    'sample':pd.DataFrame
+                }
+            DataFrame consists of schema metadata summary
+            i) schema_type : gct_metadata or h5ad_metadata i.e Column Fields (Sample)
             metdata schema definition for sample:
                 schema:{
                     "<SOURCE>": {
@@ -305,9 +325,9 @@ class OmixAtlas:
                     }
                     ... other Sources
                 }
-            schema_type : files i.e Global Fields (dataset)
+            ii) schema_type : files i.e Global Fields (dataset)
             PS :- ALL, ALL keys is not rigid for dataset level schema also
-            There it can be Source and dataset key also
+            There it can be <SOURCE> and <DATATYPE> key also
             metadata schema definition for a dataset:
                 schema:{
                         "ALL": {
@@ -319,32 +339,21 @@ class OmixAtlas:
                                 ... other fields
                             }
                         }
-            As Data Source and Data types segregation is not applicable
-            at Dataset Level Information (applicable for sample metadata only)
-            schema_type : gct_metadata i.e Row Fields (Feature)
+            iii) schema_type : gct_metadata i.e Row Fields (Feature)
             Not there right now
-
-            Output:
-                {
-                    'dataset':pd.DataFrame,
-                    'sample':pd.DataFrame
-                }
         """
 
         # get schema_type_dict
         schema_type_dict = self.get_schema_type(schema_level, data_type)
-
         # schema from API calls
-        if repo_id and schema_type_dict and isinstance(schema_type_dict, Dict):
-            schema = self.get_schema_from_api(repo_id, schema_type_dict)
-
+        if repo_key and schema_type_dict and isinstance(schema_type_dict, Dict):
+            schema = self.get_schema_from_api(
+                repo_key, schema_type_dict, source, data_type
+            )
         if schema and isinstance(schema, Dict):
-            for key, val in schema_type_dict.items():
-                if 'dataset' in key and schema[key]['data']['attributes']['schema']:
-                    schema[key] = schema[key]['data']['attributes']['schema']
-                elif 'sample' in key and schema[key]['data']['attributes']['schema']:
-                    schema[key] = schema[key]['data']['attributes']['schema']
-
+            for key, val in schema.items():
+                if schema[key]["data"]["attributes"]["schema"]:
+                    schema[key] = schema[key]["data"]["attributes"]["schema"]
         df_map = {}
         for key, val in schema.items():
             flatten_dict = self.flatten_nested_schema_dict(schema[key])
@@ -354,23 +363,32 @@ class OmixAtlas:
 
     def return_schema_data(self, df_map: dict) -> tuple:
         """
-            Return schema data as named tuple
+        Return schema data as named tuple
         """
-        if 'dataset' in df_map and 'sample' in df_map:
-            Schema = namedtuple("Schema", ["dataset", "sample"])
-            return Schema(df_map['dataset'], df_map['sample'])
-        elif 'dataset' in df_map:
-            Schema = namedtuple("Schema", "dataset")
-            return Schema(df_map['dataset'])
-        elif 'sample' in df_map:
-            Schema = namedtuple("Schema", "sample")
-            return Schema(df_map['sample'])
+        # change key value from index -> schema_level
+        # index and schema_level is in the const indexes_schema_level_map
+        schema_level_dict = {}
+        for key, value in df_map.items():
+            schema_level_key = indexes_schema_level_map[key]
+            schema_level_dict[schema_level_key] = value
+        Schema = namedtuple("Schema", (key for key, value in schema_level_dict.items()))
+        return Schema(**schema_level_dict)
 
     @deprecated(reason="use function get_schema")
-    def visualize_schema(self, repo_id: str, schema_level=['dataset', 'sample'], data_type="others") -> dict:
+    def visualize_schema(
+        self, repo_key: str, schema_level=["dataset", "sample"], source="", data_type=""
+    ) -> dict:
         """
-            Visualizing the schema of the repository depending on schema_type
-            schema_type : gct_metadata or h5ad_metadata i.e Column Fields (Sample)
+        Input params:
+                repo_key => str => <owner_name.repo_name>/<repo_id>
+                schema_level => list => Default value => ['dataset', 'sample']
+            Output:
+                {
+                    'dataset':pd.DataFrame,
+                    'sample':pd.DataFrame
+                }
+            DataFrame consists of schema metadata summary
+            i) schema_type : gct_metadata or h5ad_metadata i.e Column Fields (Sample)
             metdata schema definition for sample:
                 schema:{
                     "<SOURCE>": {
@@ -385,9 +403,9 @@ class OmixAtlas:
                     }
                     ... other Sources
                 }
-            schema_type : files i.e Global Fields (dataset)
+            ii) schema_type : files i.e Global Fields (dataset)
             PS :- ALL, ALL keys is not rigid for dataset level schema also
-            There it can be Source and dataset key also
+            There it can be <SOURCE> and <DATATYPE> key also
             metadata schema definition for a dataset:
                 schema:{
                         "ALL": {
@@ -399,31 +417,23 @@ class OmixAtlas:
                                 ... other fields
                             }
                         }
-            As Data Source and Data types segregation is not applicable
-            at Dataset Level Information (applicable for sample metadata only)
-            schema_type : gct_metadata i.e Row Fields (Feature)
+            iii) schema_type : gct_metadata i.e Row Fields (Feature)
             Not there right now
-
-            Output:
-                {
-                    'dataset':pd.DataFrame,
-                    'sample':pd.DataFrame
-                }
         """
 
         # get schema_type_dict
         schema_type_dict = self.get_schema_type(schema_level, data_type)
 
         # schema from API calls
-        if repo_id and schema_type_dict and isinstance(schema_type_dict, Dict):
-            schema = self.get_schema_from_api(repo_id, schema_type_dict)
+        if repo_key and schema_type_dict and isinstance(schema_type_dict, Dict):
+            schema = self.get_schema_from_api(
+                repo_key, schema_type_dict, source, data_type
+            )
 
         if schema and isinstance(schema, Dict):
-            for key, val in schema_type_dict.items():
-                if 'dataset' in key and schema[key]['data']['attributes']['schema']:
-                    schema[key] = schema[key]['data']['attributes']['schema']
-                elif 'sample' in key and schema[key]['data']['attributes']['schema']:
-                    schema[key] = schema[key]['data']['attributes']['schema']
+            for key, val in schema.items():
+                if schema[key]["data"]["attributes"]["schema"]:
+                    schema[key] = schema[key]["data"]["attributes"]["schema"]
 
         df_map = {}
         for key, val in schema.items():
@@ -434,78 +444,78 @@ class OmixAtlas:
 
     def get_schema_type(self, schema_level: list, data_type: str) -> dict:
         """
-            Compute schema_type based on repo_id and schema_level
-            schema_level         schema_type
-            ------------------------------------
-            dataset         ==   file
-            ----------------------------------
-            sample          ==   gct_metadata
-            -----------------------------------
-            sample and      ==    h5ad_metadata
-            single cell
+        Compute schema_type based on data_type and schema_level
+        schema_level         schema_type
+        ------------------------------------
+        dataset         ==   file
+        ----------------------------------
+        sample          ==   gct_metadata
+        -----------------------------------
+        sample and      ==    h5ad_metadata
+        single cell
         """
         if schema_level and isinstance(schema_level, list):
-            if 'dataset' in schema_level and 'sample' in schema_level:
-                if data_type == "others":
-                    schema_type_dict = {'dataset': 'files', 'sample': 'gct_metadata'}
+            if "dataset" in schema_level and "sample" in schema_level:
+                if data_type != "single_cell" or data_type == "":
+                    schema_type_dict = {"dataset": "files", "sample": "gct_metadata"}
                 elif data_type == "single_cell":
-                    schema_type_dict = {'dataset': 'files', 'sample': 'h5ad_metadata'}
+                    schema_type_dict = {"dataset": "files", "sample": "h5ad_metadata"}
                 else:
                     raise wrongParamException(
                         title="Incorrect Param Error",
-                        detail="Incorrect value of param passed data_type "
+                        detail="Incorrect value of param passed data_type ",
                     )
-            elif 'dataset' in schema_level or 'sample' in schema_level:
-                if 'dataset' in schema_level:
-                    schema_type_dict = {'dataset': 'files'}
-                elif 'sample' in schema_level:
-                    if data_type == "others":
-                        schema_type_dict = {'sample': 'gct_metadata'}
+            elif "dataset" in schema_level or "sample" in schema_level:
+                if "dataset" in schema_level:
+                    schema_type_dict = {"dataset": "files"}
+                elif "sample" in schema_level:
+                    if data_type != "single_cell" or data_type == "":
+                        schema_type_dict = {"sample": "gct_metadata"}
                     elif data_type == "single_cell":
-                        schema_type_dict = {'sample': 'h5ad_metadata'}
+                        schema_type_dict = {"sample": "h5ad_metadata"}
                     else:
                         raise wrongParamException(
                             title="Incorrect Param Error",
-                            detail="Incorrect value of param passed data_type "
+                            detail="Incorrect value of param passed data_type ",
                         )
             else:
                 raise wrongParamException(
                     title="Incorrect Param Error",
-                    detail="Incorrect value of param passed schema_level "
+                    detail="Incorrect value of param passed schema_level ",
                 )
         else:
             raise paramException(
                 title="Param Error",
-                detail="schema_level is either empty or its datatype is not correct"
+                detail="schema_level is either empty or its datatype is not correct",
             )
         return schema_type_dict
 
     def flatten_nested_schema_dict(self, nested_schema_dict: dict) -> dict:
         """
-         Flatten the nested dict
-          Input:
-          schema:{
-                    "<SOURCE>": {
-                        "<DATATYPE>": {
-                            "<FIELD_NAME>": {
-                            "type": "text | integer | object",
-                            "description": "string", (Min=1, Max=100)
-                            },
-                            ... other fields
-                        }
-                        ... other Data types
-                    }
-                    ... other Sources
-                }
-
-          Output:
-                   {
-                       'Source':source_list,
-                       'Datatype': datatype_list,
-                       'Field Name':field_name_list,
-                       'Field Description':field_desc_list,
-                       'Field Type': field_type_list
+        Flatten the nested dict
+         Input:
+         schema:{
+                   "<SOURCE>": {
+                       "<DATATYPE>": {
+                           "<FIELD_NAME>": {
+                           "type": "text | integer | object",
+                           "description": "string", (Min=1, Max=100)
+                           },
+                           ... other fields
+                       }
+                       ... other Data types
                    }
+                   ... other Sources
+               }
+
+         Output:
+                  {
+                      'Source':source_list,
+                      'Datatype': datatype_list,
+                      'Field Name':field_name_list,
+                      'Field Description':field_desc_list,
+                      'Field Type': field_type_list
+                  }
 
         """
         reformed_dict = {}
@@ -521,89 +531,86 @@ class OmixAtlas:
                     data_type_list.append(middle_key)
                     field_name_list.append(inner_key)
                     for key, value in field_values.items():
-                        if key == 'description':
+                        if key == "description":
                             field_description_list.append(field_values[key])
-                        if key == 'type':
+                        if key == "type":
                             field_type_list.append(field_values[key])
 
-        reformed_dict['Source'] = source_list
-        reformed_dict['Datatype'] = data_type_list
-        reformed_dict['Field Name'] = field_name_list
-        reformed_dict['Field Description'] = field_description_list
-        reformed_dict['Field Type'] = field_type_list
+        reformed_dict["Source"] = source_list
+        reformed_dict["Datatype"] = data_type_list
+        reformed_dict["Field Name"] = field_name_list
+        reformed_dict["Field Description"] = field_description_list
+        reformed_dict["Field Type"] = field_type_list
         return reformed_dict
 
     def nested_dict_to_df(self, schema_dict: dict) -> pd.DataFrame:
         """
-          Convert flatten dict into df and print it
-          Input:
-                {
-                       'Source':source_list,
-                       'Datatype': datatype_list,
-                       'Field Name':field_name_list,
-                       'Field Description':field_desc_list,
-                       'Field Type': field_type_list
-                }
-          Output:
-                DataFrame
+        Convert flatten dict into df and print it
+        Input:
+              {
+                     'Source':source_list,
+                     'Datatype': datatype_list,
+                     'Field Name':field_name_list,
+                     'Field Description':field_desc_list,
+                     'Field Type': field_type_list
+              }
+        Output:
+              DataFrame
         """
         pd.options.display.max_columns = None
         pd.options.display.width = None
-        multiIndex_df = pd.DataFrame.from_dict(schema_dict, orient='columns')
+        multiIndex_df = pd.DataFrame.from_dict(schema_dict, orient="columns")
         return multiIndex_df
 
     def format_type(self, data: dict) -> dict:
         """
-            Format the dict data
+        Format the dict data
         """
         if data and isinstance(data, Dict):
             return json.dumps(data, indent=4)
 
-    def insert_schema(self, repo_id: str, body: dict) -> dict:
+    def insert_schema(self, repo_key: str, body: dict) -> dict:
         """
-            Params:
-                repo_id => str => ex:- "345652035432"
-                body => dict
-                {
-                    "data": {
-                        "id": "<REPO_ID>",
-                        "type": "schema",
-                        "attributes": {
-                        "schema_type": "files | gct_metadata | h5ad_metadata",
-                        "schema": {
-                            ... field definitions
-                        }
-                        }
+        Params:
+            repo_key => str => <owner_name.repo_name> / <repo_id>
+            body => dict
+            {
+                "data": {
+                    "id": "<REPO_KEY>",
+                    "type": "schema",
+                    "attributes": {
+                    "schema_type": "files | gct_metadata | h5ad_metadata",
+                    "schema": {
+                        ... field definitions
+                    }
                     }
                 }
+            }
         """
-        if repo_id and body and isinstance(body, dict):
+        if repo_key and body and isinstance(body, dict):
             body = json.dumps(body)
             try:
-                schema_base_url = f'{self.discover_url}/repositories'
-                url = f"{schema_base_url}/{repo_id}/schemas"
+                schema_base_url = f"{self.discover_url}/repositories"
+                url = f"{schema_base_url}/{repo_key}/schemas"
                 resp = self.session.post(url, data=body)
                 error_handler(resp)
                 return resp.text
             except Exception as err:
-                raise apiErrorException(
-                    title="API exception err",
-                    detail=err
-                )
+                raise apiErrorException(title="API exception err", detail=err)
         else:
             raise apiErrorException(
                 title="Param Error",
-                detail="Params are either empty or its datatype is not correct"
+                detail="Params are either empty or its datatype is not correct",
             )
 
-    def update_schema(self, repo_id: str, body: dict) -> dict:
+    def update_schema(self, repo_key: str, body: dict) -> dict:
         """
         Params:
-                repo_id => str => ex:- "345652035432"
+                repo_key => str => <owner_name.repo_name> / <repo_id>
                 body => dict
                 {
                     "data": {
-                        "id": "<REPO_ID>",
+                        "id": "<REPO_KEY>",
                         "type": "schema",
                         "attributes": {
                         "schema_type": "files | gct_metadata | h5ad_metadata",
@@ -614,24 +621,21 @@ class OmixAtlas:
                     }
                 }
         """
-        schema_type = body['data']['attributes']['schema_type']
-        schema_base_url = f'{self.discover_url}/repositories'
-        url = f"{schema_base_url}/{repo_id}/schemas/{schema_type}"
-        if repo_id and body and isinstance(body, dict):
+        schema_type = body["data"]["attributes"]["schema_type"]
+        schema_base_url = f"{self.discover_url}/repositories"
+        url = f"{schema_base_url}/{repo_key}/schemas/{schema_type}"
+        if repo_key and body and isinstance(body, dict):
             body = json.dumps(body)
             try:
                 resp = self.session.patch(url, data=body)
                 error_handler(resp)
                 return resp.text
             except Exception as err:
-                raise apiErrorException(
-                    title="API exception err",
-                    detail=err
-                )
+                raise apiErrorException(title="API exception err", detail=err)
         else:
             raise paramException(
                 title="Param Error",
-                detail="Params are either empty or its datatype is not correct"
+                detail="Params are either empty or its datatype is not correct",
             )
 
     # ? DEPRECATED
@@ -649,13 +653,13 @@ class OmixAtlas:
         error_handler(response)
         return response.json()
 
-    def save_to_workspace(self, repo_id: str, dataset_id: str,
-                          workspace_id: int,
-                          workspace_path: str) -> json:
-        '''
-            Function for saving data from omixatlas to workspaces.
-            Makes a call to v1/omixatlas/workspace_jobs
-        '''
+    def save_to_workspace(
+        self, repo_id: str, dataset_id: str, workspace_id: int, workspace_path: str
+    ) -> json:
+        """
+        Function for saving data from omixatlas to workspaces.
+        Makes a call to v1/omixatlas/workspace_jobs
+        """
         url = f"{self.resource_url}/workspace_jobs"
         params = {"action": "copy"}
         payload = {
@@ -665,38 +669,35 @@ class OmixAtlas:
                     "dataset_id": dataset_id,
                     "repo_id": repo_id,
                     "workspace_id": workspace_id,
-                    "workspace_path": workspace_path
-                }
+                    "workspace_path": workspace_path,
+                },
             }
         }
-        response = self.session.post(url,
-                                     data=json.dumps(payload),
-                                     params=params)
+        response = self.session.post(url, data=json.dumps(payload), params=params)
         error_handler(response)
         if response.status_code == 200:
             logging.basicConfig(level=logging.INFO)
-            logging.info(f'Data Saved to workspace={workspace_id}')
+            logging.info(f"Data Saved to workspace={workspace_id}")
         return response.json()
 
     def format_converter(self, repo_key: str, dataset_id: str, to: str) -> None:
         """
         Function to convert a file to maf format.
         """
-        if(not (repo_key and isinstance(repo_key, str))):
-            raise InvalidParameterException('repo_id/repo_name')
-        if(not (dataset_id and isinstance(dataset_id, str))):
-            raise InvalidParameterException('dataset_id')
-        if(not (to and isinstance(to, str))):
-            raise InvalidParameterException('convert_to')
+        if not (repo_key and isinstance(repo_key, str)):
+            raise InvalidParameterException("repo_id/repo_name")
+        if not (dataset_id and isinstance(dataset_id, str)):
+            raise InvalidParameterException("dataset_id")
+        if not (to and isinstance(to, str)):
+            raise InvalidParameterException("convert_to")
         ssl._create_default_https_context = ssl._create_unverified_context
         response_omixatlas = self.omixatlas_summary(repo_key)
-        data = response_omixatlas.get('data')
-        repo_name = data.get('repo_name')
+        data = response_omixatlas.get("data")
+        repo_name = data.get("repo_name")
         index_name = data.get("indexes", {}).get("files")
-        if(index_name is None):
+        if index_name is None:
             raise paramException(
-                title='Param Error',
-                detail='Repo entered is not an omixatlas.'
+                title="Param Error", detail="Repo entered is not an omixatlas."
             )
         elastic_url = f"{self.elastic_url}/{index_name}/_search"
         query = {
@@ -710,31 +711,31 @@ class OmixAtlas:
             }
         }
         data_type = helpers.get_data_type(self, elastic_url, query)
-        if(data_type in DATA_TYPES):
+        if data_type in DATA_TYPES:
             mapped_list = DATA_TYPES[data_type][0]
-            if(to in mapped_list['format']):
-                supported_repo = mapped_list['supported_repo']
+            if to in mapped_list["format"]:
+                supported_repo = mapped_list["supported_repo"]
                 repo_found = False
                 for details in supported_repo:
-                    if(repo_name == details['name']):
-                        header_mapping = details['header_mapping']
+                    if repo_name == details["name"]:
+                        header_mapping = details["header_mapping"]
                         repo_found = True
-                if(not repo_found):
+                if not repo_found:
                     raise paramException(
                         title="Param Error",
                         detail=f"Incompatible repository error: Repository:'{repo_name}' not yet \
-                                 incorporated for converter function"
+                                 incorporated for converter function",
                     )
                 helpers.file_conversion(self, repo_name, dataset_id, to, header_mapping)
             else:
                 raise paramException(
                     title="Param Error",
-                    detail=f"Incompatible dataformat error: data format= {to} not yet incorporated for converter function"
+                    detail=f"Incompatible dataformat error: data format= {to} not yet incorporated for converter function",
                 )
         else:
             raise paramException(
                 title="Param Error",
-                detail=f"Incompatible dataype error: data_type={data_type} not yet incorporated for converter function"
+                detail=f"Incompatible dataype error: data_type={data_type} not yet incorporated for converter function",
             )
         logging.basicConfig(level=logging.INFO)
         logging.info("File converted successfully!")
